@@ -30,7 +30,7 @@
 
 /*!
 	\file
-	\version \$Id: EbmlDummy.cpp 639 2004-07-09 20:59:14Z mosu $
+	\version \$Id$
 	\author Steve Lhomme     <robux4 @ users.sf.net>
 */
 #include "ebml/EbmlDummy.h"
@@ -42,4 +42,9 @@ DEFINE_EBML_CLASS_ORPHAN(EbmlDummy, 0xFF, 1, "DummyElement");
 
 const EbmlId EbmlDummy::DummyRawId = Id_EbmlDummy;
 
+EbmlDummy::operator const EbmlId &()
+{
+    return DummyId;
+}
+
 END_LIBEBML_NAMESPACE
