@@ -30,7 +30,7 @@
 
 /*!
 	\file
-	\version \$Id: EbmlFloat.cpp 347 2010-06-26 09:07:13Z robux4 $
+	\version \$Id$
 	\author Steve Lhomme     <robux4 @ users.sf.net>
 */
 
@@ -67,21 +67,26 @@ void EbmlFloat::SetDefaultValue(double aValue)
     SetDefaultIsSet();
 }
 
-const double EbmlFloat::DefaultVal() const
+double EbmlFloat::DefaultVal() const
 {
     assert(DefaultISset());
     return DefaultValue;
 }
 
-EbmlFloat::operator const float() const {return float(Value);}
-EbmlFloat::operator const double() const {return double(Value);}
+EbmlFloat::operator float() const {return float(Value);}
+EbmlFloat::operator double() const {return double(Value);}
 
+double EbmlFloat::GetValue() const {return Value;}
+
+EbmlFloat & EbmlFloat::SetValue(double NewValue) {
+  return *this = NewValue;
+}
 
 /*!
 	\todo handle exception on errors
 	\todo handle 10 bits precision
 */
-filepos_t EbmlFloat::RenderData(IOCallback & output, bool bForceRender, bool bWithDefault)
+filepos_t EbmlFloat::RenderData(IOCallback & output, bool /* bForceRender */, bool /* bWithDefault */)
 {
 	assert(GetSize() == 4 || GetSize() == 8);
 
@@ -102,7 +107,7 @@ filepos_t EbmlFloat::RenderData(IOCallback & output, bool bForceRender, bool bWi
 	return GetSize();
 }
 
-uint64 EbmlFloat::UpdateSize(bool bWithDefault, bool bForceRender)
+uint64 EbmlFloat::UpdateSize(bool bWithDefault, bool  /* bForceRender */)
 {
 	if (!bWithDefault && IsDefaultValue())
 		return 0;
