@@ -30,7 +30,7 @@
 
 /*!
 	\file
-	\version \$Id: EbmlUInteger.cpp 347 2010-06-26 09:07:13Z robux4 $
+	\version \$Id$
 	\author Steve Lhomme     <robux4 @ users.sf.net>
 	\author Moritz Bunkus <moritz @ bunkus.org>
 */
@@ -75,11 +75,16 @@ EbmlUInteger::operator uint16() const {return uint16(Value);}
 EbmlUInteger::operator uint32() const {return uint32(Value);}
 EbmlUInteger::operator uint64() const {return Value;}
 
+uint64 EbmlUInteger::GetValue() const {return Value;}
+
+EbmlUInteger & EbmlUInteger::SetValue(uint64 NewValue) {
+  return *this = NewValue;
+}
 
 /*!
 	\todo handle exception on errors
 */
-filepos_t EbmlUInteger::RenderData(IOCallback & output, bool bForceRender, bool bWithDefault)
+filepos_t EbmlUInteger::RenderData(IOCallback & output, bool /* bForceRender */, bool /* bWithDefault */)
 {
 	binary FinalData[8]; // we don't handle more than 64 bits integers
 	
@@ -97,7 +102,7 @@ filepos_t EbmlUInteger::RenderData(IOCallback & output, bool bForceRender, bool
 	return GetSize();
 }
 
-uint64 EbmlUInteger::UpdateSize(bool bWithDefault, bool bForceRender)
+uint64 EbmlUInteger::UpdateSize(bool bWithDefault, bool /* bForceRender */)
 {
 	if (!bWithDefault && IsDefaultValue())
 		return 0;
